AutoTUI
======

helpers for creating TUIs with persistent data

TODO


## Installation

#### Requires:

This requires `python3.8+`, specifically for modern [`typing`](https://docs.python.org/3/library/typing.html) support.

To install with pip, run:

    pip3 install autotui

## Run

```
TODO: Fill this out

Usage: ...
```

# Tests

    pip install pytest
    pytest  # in the root directory
